1.0.0 API documentation: GLM_EXT_matrix_uint2x3

| 1.0.0 API documentation

Typedefs
GLM_EXT_matrix_uint2x3
Stable extensions

## Typedefs
typedef mat< 2, 3, uint, defaultp > | umat2x3
| Unsigned integer 2x3 matrix. More...

## Detailed Description

Include <glm/ext/matrix_uint2x3.hpp> to use the features of this extension.

Defines a number of matrices with integer types.

## Typedef Documentation

## ◆ umat2x3

typedef mat< 2, 3, uint, defaultp > umat2x3

Unsigned integer 2x3 matrix.

See also
  GLM_EXT_matrix_uint2x3
  GLM_GTC_matrix_integer

Definition at line 30 of file matrix_uint2x3.hpp.